﻿'***************************************************************************************************
'   枠線の色を変えられるグループボックス                  ColoredGroupBox1(Class)
'
'   作成者:井上治  URL:https://www.ne.jp/asahi/excel/inoue/ [Excelでお仕事!]
'***************************************************************************************************
' 変更日付 Rev     変更履歴内容-------------------------------------------------------------------->
' 15/08/25(1.0.0.0)新規作成
' 15/08/26(1.0.0.0)描画不良を修正
'***************************************************************************************************
Public Class ColoredGroupBox1
    Inherits GroupBox
    '-----------------------------------------------------------------------------------------------
    ' プロパティ保持値
    Private g_objBorderColor As Color           ' 枠線色
    Private g_intAddWidth As Integer = 0        ' 文字列幅加算値(調整用)
    Private g_intAdjustHeight As Integer = 10   ' 文字列代替高(文字列がない時の調整用)

    '***********************************************************************************************
    '   ■■■ イベント
    '***********************************************************************************************
    '* 処理名　：New
    '* 機能　　：初期化
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2015年08月25日
    '* 作成者　：井上　治
    '* 更新日　：2015年08月25日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Public Sub New()
        '-------------------------------------------------------------------------------------------
        MyBase.New()
        Me.g_objBorderColor = Color.DarkGray
        'Me.Font = New Font("ＭＳ ゴシック", 9)
        'Me.ForeColor = Color.Purple
    End Sub

    '***********************************************************************************************
    '* 処理名　：OnPaint
    '* 機能　　：描画イベント
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2015年08月25日
    '* 作成者　：井上　治
    '* 更新日　：2015年08月26日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Protected Overrides Sub OnPaint(ByVal e As PaintEventArgs)
        '-------------------------------------------------------------------------------------------
        ' ↓この方法では横幅が正確ではない。g_intAddWidthで調整する。
        Dim tSize As Size = TextRenderer.MeasureText(Me.Text, Me.Font)
        Dim intTextHeight As Integer, intTextWidth As Integer
        If Me.Text.Length <> 0 Then
            ' 文字列がある時は文字列の高さ
            intTextHeight = tSize.Height
            intTextWidth = tSize.Width
        Else
            ' 文字列がない時は文字列代替高で充当
            intTextHeight = g_intAdjustHeight
            intTextWidth = 0
        End If
        ' 描画するときはこのGroupBoxの左上の点が(0,0)である
        Dim borderTop As Integer = intTextHeight / 2
        Dim borderHeight As Integer = Math.Max(0, Me.Height - intTextHeight / 2)
        If intTextHeight > Me.Height - 1 Then
            ' 高さが低くなったときに下線が消えないように
            tSize.Height = Me.Height - 1
        End If
        Dim borderRect As Rectangle = New Rectangle(0, borderTop, Me.Width, borderHeight)
        Dim textRect As Rectangle = New Rectangle(6, 0, intTextWidth + g_intAddWidth, tSize.Height)
        ControlPaint.DrawBorder(e.Graphics, borderRect, Me.g_objBorderColor, ButtonBorderStyle.Solid)
        e.Graphics.FillRectangle(New SolidBrush(Me.BackColor), textRect)
        e.Graphics.DrawString(Me.Text, Me.Font, New SolidBrush(Me.ForeColor), textRect)
    End Sub

    '***********************************************************************************************
    '   ■■■ プロパティ
    '***********************************************************************************************
    '   枠線色(Color)
    '-----------------------------------------------------------------------------------------------
    Public Property BorderColor As Color
        Get
            Return Me.g_objBorderColor
        End Get
        Set(value As Color)
            Me.g_objBorderColor = value
        End Set
    End Property

    '===============================================================================================
    '   文字列幅加算値(Integer)
    '-----------------------------------------------------------------------------------------------
    Public Property AddWidth As Integer
        Get
            Return g_intAddWidth
        End Get
        Set(value As Integer)
            g_intAddWidth = value
        End Set
    End Property

    '===============================================================================================
    '   文字列代替高(Integer)
    '-----------------------------------------------------------------------------------------------
    Public Property AdjustHeight() As Integer
        Get
            Return g_intAdjustHeight
        End Get
        Set(ByVal value As Integer)
            g_intAdjustHeight = value
        End Set
    End Property

    '---------------------------------------<< End of Source >>-------------------------------------
End Class

