﻿'***************************************************************************************************
'   フォルダ名入力コントロール                      TXT_PATHNAME(Class)
'
'   作成者:井上治  URL:https://www.ne.jp/asahi/excel/inoue/ [Excelでお仕事!]
'***************************************************************************************************
' 変更日付 Rev     変更履歴内容-------------------------------------------------------------------->
' 12/09/05(1.0.0.0)Entried､Deletedイベントの発生条件を変更(未変更時は発生させない)
' 13/02/05(1.0.1.1)GP_ShowFolderBrowserDialogに親フォームのRefresh動作を追加
' 13/08/07(1.0.1.2)エラーメッセージの編集を修正
' 14/05/26(1.0.1.3)InStrRev⇒LastIndexOf関数変更
' 14/10/15(1.0.2.0)FolderBrowserDialogはコントロールから直接記述に変更
'***************************************************************************************************
Imports System.IO
Public Class TXT_PATHNAME
    '-----------------------------------------------------------------------------------------------
    ' 表示モード(0=通常、1=下層フォルダのみ(ToolTipあり)、2=下層フォルダのみ(ToolTipなし))
    Private g_intDispMode As Integer = 0
    ' 表示文字列幅(Byte数)
    Private g_intDispFileNameBytes As Integer = 0
    ' 項目タイトル
    Private g_strTitle As String = "フォルダ名"
    ' フォルダの参照の説明テキスト
    Private g_strDescriptionText As String = "フォルダを指定して下さい。"
    ' 親ウィンドウ名
    Private g_strWindowName As String = ""
    ' 初回ToolTip表示
    Private g_strToolTipText As String = _
        "フォルダウィンドウからドラッグ＆ドロップするか、" & ControlChars.CrLf & _
        "ダブルクリックして下さい。"
    '' 右\付加区分
    'Private g_blnEndsWithPathSeparator As Boolean = True
    ' 右クリックメニュー「削除」使用
    Private g_blnUseContextMenu As Boolean = False
    ' 右クリックメニューの表示テキスト
    Private g_strContextMenuText As String = "フォルダ消去(&D)"
    ' 右クリックメニューのToolTip表示テキスト
    Private g_strContextMenuToolTipText As String = "このフォルダ指定を消去します。"
    '-----------------------------------------------------------------------------------------------
    ' フォルダ名(フルパス)
    Private g_strPathName As String = ""

    '***********************************************************************************************
    '   ■■■ コントロールイベント
    '***********************************************************************************************
    '* 処理名　：Entried
    '* 機能　　：ファイル名登録イベント(Entried) ※カスタムイベント
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Public Event Entried(ByVal sender As System.Object, _
                         ByVal e As System.EventArgs)

    '***********************************************************************************************
    '* 処理名　：Deleted
    '* 機能　　：ファイル名削除イベント(Deleted) ※カスタムイベント
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Public Event Deleted(ByVal sender As System.Object, _
                         ByVal e As System.EventArgs)

    '***********************************************************************************************
    '* 処理名　：TXT_PATHNAME_DoubleClick
    '* 機能　　：フォルダ名テキストボックスイベント(DoubleClick)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub TXT_PATHNAME_DoubleClick(ByVal sender As Object, _
                                         ByVal e As System.EventArgs) _
                                         Handles Me.DoubleClick
        '-------------------------------------------------------------------------------------------
        ' フォルダ参照ダイアログの表示
        Call GP_ShowFolderBrowserDialog()
    End Sub

    '***********************************************************************************************
    '* 処理名　：TXT_PATHNAME_DragDrop
    '* 機能　　：フォルダ名テキストボックスイベント(DragDrop)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub TXT_PATHNAME_DragDrop(ByVal sender As Object, _
                                      ByVal e As System.Windows.Forms.DragEventArgs) _
                                      Handles Me.DragDrop
        '-------------------------------------------------------------------------------------------
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            Dim tblDrags As String() = CType(e.Data.GetData(DataFormats.FileDrop), String())
            For Each strDrag As String In tblDrags
                If Directory.Exists(strDrag) Then
                    Call GP_SetPathName(strDrag)
                    Exit For
                End If
            Next strDrag
            e.Effect = DragDropEffects.Copy
            ' 本ウィンドウをアクティブにする
            If g_strWindowName.Length = 0 Then
                g_strWindowName = Me.TopLevelControl.Text
            End If
            Try
                AppActivate(g_strWindowName)
            Catch ex As Exception
                ' エラー無視
            End Try
        End If
    End Sub

    '***********************************************************************************************
    '* 処理名　：TXT_PATHNAME_DragEnter
    '* 機能　　：フォルダ名テキストボックスイベント(DragEnter)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub TXT_PATHNAME_DragEnter(ByVal sender As Object, _
                                       ByVal e As System.Windows.Forms.DragEventArgs) _
                                       Handles Me.DragEnter
        '-------------------------------------------------------------------------------------------
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            e.Effect = DragDropEffects.Copy
        End If
    End Sub

    '***********************************************************************************************
    '* 処理名　：TXT_PATHNAME_Resize
    '* 機能　　：フォルダ名テキストボックスイベント(Resize)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub TXT_PATHNAME_Resize(ByVal sender As Object, _
                                    ByVal e As System.EventArgs) Handles Me.Resize
        '-------------------------------------------------------------------------------------------
        ' 表示幅算出
        g_intDispFileNameBytes = FP_GetLengthShowable(Me)
        ' コンテキストメニューの初期化(空メニュー)
        Dim objCunMnu As New ContextMenuStrip
        Me.ContextMenuStrip = objCunMnu
        ' 初期ツールチップ
        ToolTip1.SetToolTip(Me, g_strToolTipText)
    End Sub

    '***********************************************************************************************
    '* 処理名　：ContextDelete_Click
    '* 機能　　：右クリックメニュー「削除」イベント(Click)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub ContextDelete_Click(ByVal sender As Object, _
                                    ByVal e As System.EventArgs)
        '-------------------------------------------------------------------------------------------
        ' フォルダ名のクリア
        Call GP_ClearPathName(e)
    End Sub

    '***********************************************************************************************
    '   ■■■ サブ処理
    '***********************************************************************************************
    '* 処理名　：GP_ShowFolderBrowserDialog
    '* 機能　　：フォルダ参照ダイアログの表示
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2014年10月15日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub GP_ShowFolderBrowserDialog()
        '-------------------------------------------------------------------------------------------
        ' 既に登録がある場合はカレントフォルダを移動
        Dim strCurrPathName As String = My.Computer.FileSystem.CurrentDirectory
        If ((g_strPathName.Length <> 0) AndAlso (Directory.Exists(g_strPathName))) Then
            My.Computer.FileSystem.CurrentDirectory = g_strPathName
        End If
        '-------------------------------------------------------------------------------------------
        ' フォルダ参照ダイアログよりファイル指定を受ける
        Using objFolderDialog As New FolderBrowserDialog
            With objFolderDialog
                .Description = g_strDescriptionText
                .SelectedPath = g_strPathName
                .ShowNewFolderButton = False
                Dim intResult As DialogResult = .ShowDialog(Me.TopLevelControl)
                Me.TopLevelControl.Refresh()
                Application.DoEvents()
                If intResult = Windows.Forms.DialogResult.OK Then
                    Call GP_SetPathName(.SelectedPath)
                End If
            End With
        End Using
        '-------------------------------------------------------------------------------------------
        ' カレントフォルダを戻す
        My.Computer.FileSystem.CurrentDirectory = strCurrPathName
    End Sub

    '***********************************************************************************************
    '* 処理名　：GP_SetPathName
    '* 機能　　：フォルダ名のセット(表示幅に合わせる)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：Arg1 = フォルダ名(String)
    '* 　　　　　Arg2 = System.EventArgs(Object)        ※Option
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2014年10月15日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub GP_SetPathName(ByVal strPathName As String, _
                               Optional ByVal e As System.EventArgs = Nothing)
        '-------------------------------------------------------------------------------------------
        ' 直前のフォルダ名を退避
        Dim prevPathName As String = g_strPathName
        '' 右\付加指定の基づいたフルパスフォルダ名
        'g_strPathName = FP_EndsWithPathSeparator(strPathName, g_blnEndsWithPathSeparator)
        ' フルパスフォルダ名を退避
        g_strPathName = strPathName
        '-------------------------------------------------------------------------------------------
        ' 表示モード指定による表示
        Select Case g_intDispMode
            Case 1                      ' 最下層フォルダのみ(ToolTipあり:右\なし)
                'Me.Text = FP_GetFileName(FP_EndsWithPathSeparator(g_strPathName, False))
                Me.Text = FP_GetFileName(g_strPathName)
                ' 元のフォルダ名はTooltipに表示
                ToolTip1.SetToolTip(Me, g_strPathName)
            Case 2                      ' 最下層フォルダのみ(ToolTipなし:右\なし)
                'Me.Text = FP_GetFileName(FP_EndsWithPathSeparator(g_strPathName, False))
                Me.Text = FP_GetFileName(g_strPathName)
                ToolTip1.SetToolTip(Me, Nothing)
            Case Else                   ' 通常(原則フルパス表示)
                ' フルパスフォルダ名から表示用ファイル名を取得
                Dim strPathName2 As String = _
                    FP_GetDispPathName(g_strPathName, g_intDispFileNameBytes)
                Me.Text = strPathName2
                If strPathName2 <> g_strPathName Then
                    ' 元のフォルダ名はTooltipに表示
                    ToolTip1.SetToolTip(Me, g_strPathName)
                Else
                    ToolTip1.SetToolTip(Me, Nothing)
                End If
        End Select
        '-------------------------------------------------------------------------------------------
        ' Entriedイベントを発生させる(直前のフォルダ名と異なる場合のみ)
        If g_strPathName <> prevPathName Then
            If strPathName.Length <> 0 Then
                RaiseEvent Entried(Me, e)
            Else
                RaiseEvent Deleted(Me, e)
            End If
        End If
    End Sub

    '***********************************************************************************************
    '* 処理名　：GP_ClearPathName
    '* 機能　　：フォルダ名のクリア
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：Arg1 = System.EventArgs(Object)        ※Option
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub GP_ClearPathName(Optional ByVal e As System.EventArgs = Nothing)
        '-------------------------------------------------------------------------------------------
        ' 直前のフォルダ名を退避
        Dim prevPathName As String = g_strPathName
        '-------------------------------------------------------------------------------------------
        ' 消去
        g_strPathName = String.Empty
        Me.Text = String.Empty
        ToolTip1.SetToolTip(Me, Nothing)
        '-------------------------------------------------------------------------------------------
        ' Deletedイベントを発生させる
        If prevPathName.Length <> 0 Then
            RaiseEvent Deleted(Me, e)
        End If
    End Sub

    '***********************************************************************************************
    '* 処理名　：FP_GetErrValue
    '* 機能　　：エラー値の採取
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：エラー値(Integer)      0=正常,1=無指定,2=不存在,9=I/Oエラー
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Function FP_GetErrValue() As Integer
        '-------------------------------------------------------------------------------------------
        If g_strPathName.Length = 0 Then
            Return 1                        ' 1=無指定
        End If
        Try
            If Directory.Exists(g_strPathName) Then
                Return 0                    ' 0=正常
            Else
                Return 2                    ' 2=不存在
            End If
        Catch ex As Exception
            Return 9                        ' 9=I/Oエラー(権限無し等)
        End Try
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_GetErrMSG
    '* 機能　　：エラーメッセージの採取
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：エラーメッセージ(String)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Function FP_GetErrMSG() As String
        '-------------------------------------------------------------------------------------------
        ' タイトルが｢フォルダ名の指定｣などとなっている場合は｢の指定｣を除去
        Dim strTitle As String = g_strTitle
        If g_strTitle.Contains("の") Then
            strTitle = g_strTitle.Substring(0, g_strTitle.LastIndexOf("の"))
        End If
        '-------------------------------------------------------------------------------------------
        If g_strPathName.Length = 0 Then
            Return "「" & strTitle & "」が指定されていません。"
        End If
        Try
            If Directory.Exists(g_strPathName) Then
                Return String.Empty
            Else
                Return "「" & strTitle & "」のフォルダが実在しません。" & ControlChars.CrLf & g_strPathName
            End If
        Catch ex As Exception
            Return "「" & strTitle & "」I/Oエラー" & ControlChars.CrLf & ex.Message & ControlChars.CrLf & g_strPathName
        End Try
    End Function

    '***********************************************************************************************
    '   ■■■ メソッド(外部利用)
    '***********************************************************************************************
    '* 処理名　：ShowFolderBrowserDialog
    '* 機能　　：フォルダ参照ダイアログの表示(｢参照｣ボタン呼出し用)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Public Sub ShowFolderBrowserDialog()
        '-------------------------------------------------------------------------------------------
        ' フォルダ参照ダイアログの表示
        Call GP_ShowFolderBrowserDialog()
    End Sub

    '***********************************************************************************************
    '* 処理名　：GetDispPathName
    '* 機能　　：表示用フォルダ名の取得(表示幅に合わせる)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：表示用フォルダ名(String)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Public Function GetDispPathName(ByVal FullPathName As String, _
                                    ByVal DispByteSize As Integer) As String
        '-------------------------------------------------------------------------------------------
        Return FP_GetDispPathName(FullPathName, DispByteSize)
    End Function

    '***********************************************************************************************
    '   ■■■ プロパティ
    '***********************************************************************************************
    '   フォルダ名(String)  ※フルパス
    '-----------------------------------------------------------------------------------------------
    Public Property PathName() As String
        Get
            Return g_strPathName
        End Get
        Set(ByVal value As String)
            If value.Length <> 0 Then
                Call GP_SetPathName(value)
            Else
                Call GP_ClearPathName()
            End If
        End Set
    End Property

    '===============================================================================================
    '   表示モード(Integer)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property DispMode() As Integer
        Set(ByVal value As Integer)
            g_intDispMode = value
        End Set
    End Property

    '===============================================================================================
    '   表示文字列バイト数(Integer)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property DispFileNameBytes() As Integer
        Set(ByVal value As Integer)
            g_intDispFileNameBytes = value
        End Set
    End Property

    '===============================================================================================
    '   項目タイトル(String)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property Title() As String
        Set(ByVal value As String)
            g_strTitle = value
        End Set
    End Property

    '===============================================================================================
    '   フォルダの参照の説明テキスト(String)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property DescriptionText() As String
        Set(ByVal value As String)
            g_strDescriptionText = value
        End Set
    End Property

    '===============================================================================================
    '   親フォームのウィンドウ名(String)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property WindowName() As String
        Set(ByVal value As String)
            g_strWindowName = value
        End Set
    End Property

    '===============================================================================================
    '   ツールチップのデフォルト値(String)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property DefaultToolTipText() As String
        Set(ByVal value As String)
            g_strToolTipText = value
        End Set
    End Property

    ''=====================================================================================
    ''   右\付加区分(Boolean)
    ''-------------------------------------------------------------------------------------
    'Public WriteOnly Property EndsWithPathSeparator() As Boolean
    '    Set(ByVal value As Boolean)
    '        g_blnEndsWithPathSeparator = value
    '    End Set
    'End Property

    '===============================================================================================
    '   右クリックメニューの表示テキスト(String)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property ContextMenuText() As String
        Set(ByVal value As String)
            g_strContextMenuText = value
        End Set
    End Property

    '===============================================================================================
    '   右クリックメニューのToolTip表示テキスト(String)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property ContextMenuToolTipText() As String
        Set(ByVal value As String)
            g_strContextMenuToolTipText = value
        End Set
    End Property

    '===============================================================================================
    '   右クリックメニュー「削除」の追加(Boolean)
    '-----------------------------------------------------------------------------------------------
    Public WriteOnly Property UseContextMenu() As Boolean
        Set(ByVal value As Boolean)
            If value AndAlso Not g_blnUseContextMenu Then
                ' コンテキストメニューの追加
                Dim objCunMnu As New ContextMenuStrip
                Dim objConMnuDel As New ToolStripMenuItem
                Me.ContextMenuStrip = objCunMnu
                With objCunMnu
                    ' コンテキストメニューにメニューアイテムを追加
                    .Items.Add(objConMnuDel)
                    With objConMnuDel
                        .Text = g_strContextMenuText
                        .ToolTipText = g_strContextMenuToolTipText
                        ' コンテキストメニューボタンにClickイベントを割り付け
                        AddHandler .Click, AddressOf ContextDelete_Click
                    End With
                End With
                g_blnUseContextMenu = True
            ElseIf Not value AndAlso g_blnUseContextMenu Then
                ' コンテキストメニューを削除
                Try
                    Me.ContextMenuStrip.Items.Clear()
                Catch ex As Exception

                End Try
                g_blnUseContextMenu = False
            End If
        End Set
    End Property

    ''=====================================================================================
    ''   フォルダ名(String)  ※最終レベル
    ''-------------------------------------------------------------------------------------
    'Public ReadOnly Property Folder() As String
    '    Get
    '        Return FP_GetFileName(FP_EndsWithPathSeparator(g_strPathName, False))
    '    End Get
    'End Property

    '===============================================================================================
    '   エラー値(Integer)
    '-----------------------------------------------------------------------------------------------
    Public ReadOnly Property ErrValue() As Integer
        Get
            Return FP_GetErrValue()
        End Get
    End Property

    '===============================================================================================
    '   エラーメッセージ(String)
    '-----------------------------------------------------------------------------------------------
    Public ReadOnly Property ErrMSG() As String
        Get
            Return FP_GetErrMSG()
        End Get
    End Property

    '---------------------------------------<< End of Source >>-------------------------------------
End Class

