﻿'***************************************************************************************************
'   フォルダ名・ファイル名入力コントロール用共通記述    modPathFileControl(Module)
'
'   作成者:井上治  URL:https://www.ne.jp/asahi/excel/inoue/ [Excelでお仕事!]
'***************************************************************************************************
' 変更日付 Rev     変更履歴内容-------------------------------------------------------------------->
' 14/05/22(1.6.12.12)[全般修正]フルパス編集をPath.Combineメソッドで行なうように変更の対応
' 14/05/23(1.6.12.12)[全般修正]ファイル名､拡張子取得をFileInfo利用に変更
' 14/08/14(1.7.1.5)参照モード時の文字色、背景色項目を追加
' 14/08/14(1.7.1.5)FP_GetFileNameにURLでの処理機能を追加
'***************************************************************************************************
Imports System.IO
Module modPathFileControl
    '-----------------------------------------------------------------------------------------------
    Private ReadOnly g_cnsYen As String = Path.DirectorySeparatorChar
    ' 標準フォント名
    Friend Const g_cnsStdFontName As String = "ＭＳ ゴシック"
    Friend Const g_cnsStdFontNameP As String = "ＭＳ Ｐゴシック"
    ' 96DPI時の標準フォントサイズ
    Friend Const g_cnsFontSize900 As Single = 9.0F
    Friend Const g_cnsFontSize975 As Single = 9.75F
    '-----------------------------------------------------------------------------------------------
    ' 参照モード時の文字色、背景色
    Friend g_objReadOnlyForeColor As Color = Color.Blue         ' 文字色
    Friend g_objReadOnlyBackColor As Color = Color.White        ' 背景色

    '***********************************************************************************************
    '   ■■■ 共通サブ処理
    '***********************************************************************************************
    '* 処理名　：FP_GetDispPathName
    '* 機能　　：表示用フォルダ名・ファイル名の取得
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：表示用フォルダ名・ファイル名(String)
    '* 引数　　：Arg1 = フルパス名(String)
    '* 　　　　　Arg2 = 表示桁数(Integer)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Function FP_GetDispPathName(ByVal strPathName As String, _
                                       ByVal intDispPathNameSize As Integer) As String
        '-------------------------------------------------------------------------------------------
        ' 表示サイズ(Byte長)に収まる場合は全桁表示
        If FP_GetByteLength(strPathName) <= intDispPathNameSize Then
            Return strPathName
        End If
        ' 各段階のフォルダに分解して中間を除去してみる
        Dim swUNC As Boolean
        Dim tblPath As String()
        If strPathName.StartsWith(g_cnsYen & g_cnsYen) Then
            ' UNCパス時は一旦先頭の｢\\｣を取る
            swUNC = True
            tblPath = strPathName.Substring(2).Split(g_cnsYen)
        Else
            ' ローカルパス時はそのまま
            swUNC = False
            tblPath = strPathName.Split(g_cnsYen)
        End If
        Dim strPathName1 As String, strPathName2 As String
        If swUNC Then
            ' UNCパス時は先頭の｢\\｣を復旧
            strPathName1 = g_cnsYen & g_cnsYen & tblPath(0) & g_cnsYen
        Else
            ' ローカルパス時はそのまま
            strPathName1 = tblPath(0) & g_cnsYen
        End If
        Dim IX1 As Integer = 1, IX2 As Integer = tblPath.GetUpperBound(0), IX3 As Integer
        ' strPathName3に編集後のファイル名をセット
        Dim strPathName3 As String = strPathName
        ' 長い方のパス名の組み合わせから表示幅に収まるように探索
        Do While IX1 <= IX2
            ' 中間を除いたパス名を再編集
            strPathName2 = tblPath(IX1)
            IX3 = IX1 + 1
            Do While IX3 <= IX2
                strPathName2 &= g_cnsYen & tblPath(IX3)
                IX3 += 1
            Loop
            strPathName3 = strPathName1 & "...\" & strPathName2
            ' Byte長が表示幅に収まればOKとする
            If FP_GetByteLength(strPathName3) <= intDispPathNameSize Then Exit Do
            IX1 += 1
        Loop
        Return strPathName3
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_GetByteLength
    '* 機能　　：文字列バイト長取得(全半角勘案)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：文字列バイト長(Integer)
    '* 引数　　：Arg1 = 対象テキスト(String)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Function FP_GetByteLength(ByVal strTEXT As String) As Integer
        '-------------------------------------------------------------------------------------------
        Dim POS As Integer = 0, intChar As Integer
        ' 1文字ずつ半角/全角を検査
        FP_GetByteLength = 0
        Do While POS < strTEXT.Length
            intChar = Asc(strTEXT.Substring(POS, 1))
            If ((intChar >= 0) AndAlso (intChar <= 255)) Then
                FP_GetByteLength += 1                       ' 半角は1バイト
            Else
                FP_GetByteLength += 2                       ' 全角は2バイト
            End If
            POS += 1
        Loop
    End Function

    ''*************************************************************************************
    ''* 処理名　：FP_EndsWithPathSeparator
    ''* 機能　　：右\付加 or 撤去
    ''-------------------------------------------------------------------------------------
    ''* 返り値　：編集後フォルダ名・ファイル名(String)
    ''* 引数　　：Arg1 = フルパス名(String)
    ''* 　　　　　Arg2 = 付加撤去指示(Boolean)
    ''-------------------------------------------------------------------------------------
    ''* 作成日　：2012年09月05日
    ''* 作成者　：井上　治
    ''* 更新日　：2012年09月05日
    ''* 更新者　：井上　治
    ''* 機能説明：
    ''* 注意事項：※削除予定
    ''*************************************************************************************
    'Friend Function FP_EndsWithPathSeparator(ByVal strPathName As String, _
    '                                         ByVal blnEndsWithPathSeparator As Boolean) As String
    '    '---------------------------------------------------------------------------------
    '    If blnEndsWithPathSeparator Then
    '        ' 右\付加
    '        If Not strPathName.EndsWith(g_cnsYen) Then
    '            Return strPathName & g_cnsYen
    '        Else
    '            Return strPathName
    '        End If
    '    Else
    '        ' 右\撤去
    '        If strPathName.EndsWith(g_cnsYen) Then
    '            Return strPathName.Substring(0, strPathName.Length - 1)
    '        Else
    '            Return strPathName
    '        End If
    '    End If
    'End Function

    '***********************************************************************************************
    '* 処理名　：FP_GetFileName
    '* 機能　　：フルパスファイル名からファイル名(パス抜き)を取得(URLも対応)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：パス抜きファイル名(String)
    '* 引数　　：Arg1 = フルパス名(String)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Function FP_GetFileName(ByVal strFileName As String) As String
        '-------------------------------------------------------------------------------------------
        If strFileName.Length = 0 Then Return String.Empty
        Dim strURL As String = strFileName.ToUpper
        If ((strURL.StartsWith("HTTP://")) OrElse _
            (strURL.StartsWith("HTTPS://")) OrElse _
            (strURL.StartsWith("FTP://")) OrElse _
            (strURL.StartsWith("FTPS://"))) Then
            Dim POS As Integer = InStrRev(strFileName, "/")
            If POS >= 1 Then
                Return strFileName.Substring(POS)
            Else
                Return strFileName
            End If
        Else
            Try
                Dim objFileInfo As FileInfo = New FileInfo(strFileName)
                Return objFileInfo.Name
            Catch ex As Exception
                Return strFileName
            End Try
        End If
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_GetPathName
    '* 機能　　：フルパスファイル名からフォルダ名を取得(右\無し)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：フォルダ名(String)
    '* 引数　　：Arg1 = フルパス名(String)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Function FP_GetPathName(ByVal strFileName As String) As String
        '-------------------------------------------------------------------------------------------
        If strFileName.Length = 0 Then Return String.Empty
        Dim objFileInfo As FileInfo = New FileInfo(strFileName)
        Return objFileInfo.DirectoryName
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_GetFileExtension
    '* 機能　　：フルパスファイル名から拡張子を取得
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：拡張子(String)
    '* 引数　　：Arg1 = フルパス名(String)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Function FP_GetFileExtension(ByVal strFileName As String) As String
        '-------------------------------------------------------------------------------------------
        If strFileName.Length = 0 Then Return String.Empty
        Dim objFileInfo As FileInfo = New FileInfo(strFileName)
        Return objFileInfo.Extension
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_GetLengthShowable
    '* 機能　　：テキストボックスの表示可能バイト数取得
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：表示可能バイト数(Integer)
    '* 引数　　：Arg1 = 対象テキストボックス(Object)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Function FP_GetLengthShowable(ByVal objTextBox As TextBox) As Integer
        '-------------------------------------------------------------------------------------------
        Dim cnsStrings As String = New String("a", 5000)
        Dim IX As Integer = 0
        With objTextBox
            Dim intWidth As Integer = .Width
            .Text = cnsStrings
            Do While IX <= .TextLength
                ' 文字の表示位置がテキストボックスの幅を超える文字位置を取得
                If .GetPositionFromCharIndex(IX).X >= intWidth Then
                    ' 1文字戻して終了
                    IX -= 1
                    Exit Do
                End If
                IX += 1
            Loop
            .Text = String.Empty
        End With
        Return IX
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_GetLengthShowableDGV
    '* 機能　　：DataGridViewの表示可能バイト数取得
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：表示可能バイト数(Integer)
    '* 引数　　：Arg1 = 対象DataGridView(Object)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2012年09月05日
    '* 作成者　：井上　治
    '* 更新日　：2012年09月05日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Friend Function FP_GetLengthShowableDGV(ByVal objDGV As DataGridView) As Integer
        '-------------------------------------------------------------------------------------------
        Dim intWidth As Integer = objDGV.Columns(0).Width - 6   ' 自動縮小相当分を減算
        Dim objFont As Font = objDGV.Columns(0).DefaultCellStyle.Font
        ' テキストボックスを一時的に作成して表示可能バイト数取得
        Dim objTextBox As New TextBox
        objTextBox.Font = objFont
        objTextBox.Width = intWidth
        Dim intBytes As Integer = FP_GetLengthShowable(objTextBox)
        objTextBox.Dispose()
        objTextBox = Nothing
        Return intBytes
    End Function

    '---------------------------------------<< End of Source >>-------------------------------------
End Module

