﻿'***************************************************************************************************
'   ファイルを検索してExcelに一覧出力(サンプル)                   frmSearchFilesTEST1(Form)
'
'   作成者:井上治  URL:https://www.ne.jp/asahi/excel/inoue/ [Excelでお仕事!]
'***************************************************************************************************
' 変更日付 Rev   変更履歴内容---------------------------------------------------------------------->
' 17/12/02(1.0.0)新規作成
' 17/12/09(1.0.0)ファイル探索手段によるクラス分け対応
' 17/12/10(1.0.0)通常のファイル探索を再帰動作と非再帰動作の2種類に分割
'***************************************************************************************************
Imports System.IO
Public Class frmSearchFilesTEST1
    '===============================================================================================
    Private Const g_cnsStatusGuide As String = "「処理開始」ボタンで処理が開始されます。"
    ' Excelテンプレート
    Private Const g_cnsExcelTemplate As String = "SearchFilesTEST1.xltx"
    '-----------------------------------------------------------------------------------------------
    Private g_objOmitDoubleClick As clsOmitDoubleClick2         ' ダブルクリック抑制クラス
    Private g_objAboutWindow As clsAboutWindow1                 ' ウィンドウ制御関連クラス
    '-----------------------------------------------------------------------------------------------
    ' 個別変数
    Private g_intStatusLength As Integer = 100                  ' 表示できる文字数

    '***********************************************************************************************
    ' ■■■ 初期化 ■■■
    '***********************************************************************************************
    '* 処理名　：New
    '* 機能　　：初期化
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Public Sub New()
        '===========================================================================================
        ' この呼び出しは、Windows フォーム デザイナで必要です。
        InitializeComponent()
        ' フォームデザイナモード時は以下をスキップする
        If Me.DesignMode Then Exit Sub
        '-------------------------------------------------------------------------------------------
        ' ダブルクリック抑制クラスの初期化
        g_objOmitDoubleClick = New clsOmitDoubleClick2(Me)
        ' ウィンドウ制御関連クラスの初期化
        g_objAboutWindow = New clsAboutWindow1(Me)
        '-------------------------------------------------------------------------------------------
        With CCN_PATHNAME
            .Title = "ルートフォルダ"
            .WindowName = Me.Text
        End With
    End Sub

    '***********************************************************************************************
    ' ■■■ Formイベント ■■■
    '***********************************************************************************************
    '* 処理名　：Form_DragDrop
    '* 機能　　：フォームイベント(DragDrop)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub Form_DragDrop(ByVal sender As Object, _
                              ByVal e As DragEventArgs) Handles Me.DragDrop
        '-------------------------------------------------------------------------------------------
        ' ドラッグされたファイルがあるか
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            Dim tblDrags As String() = CType(e.Data.GetData(DataFormats.FileDrop), String())
            ' 複数フォルダのドラッグか
            If tblDrags.Length > 1 Then
                MessageBox2.DialogShow(Me, _
                                       "１フォルダのみドラッグして下さい。", _
                                       g_cnsProgTitle, _
                                       MessageBoxButtons.OK, _
                                       MessageBoxIcon.Exclamation)
            Else
                ' 単一フォルダのドラッグ(配列受け取りなのでループさせている)
                For Each strDrag As String In tblDrags
                    ' フォルダは実在するか
                    If Directory.Exists(strDrag) Then
                        CCN_PATHNAME.PathName = strDrag
                        Exit For
                    End If
                Next strDrag
            End If
            e.Effect = DragDropEffects.Copy
            ' 本ウィンドウをアクティブにする
            Try
                AppActivate(Me.Text)
            Catch ex As Exception
                ' エラー無視
            End Try
        End If
    End Sub

    '***********************************************************************************************
    '* 処理名　：Form_DragEnter
    '* 機能　　：フォームイベント(DragEnter)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(既定)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub Form_DragEnter(ByVal sender As Object, _
                               ByVal e As DragEventArgs) Handles Me.DragEnter
        '-------------------------------------------------------------------------------------------
        ' ファイルのドラッグか
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            e.Effect = DragDropEffects.Copy
        End If
    End Sub

    '***********************************************************************************************
    '* 処理名　：Form_FormClosed
    '* 機能　　：フォームイベント(FormClosed)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(デフォルト)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub Form_FormClosed(ByVal sender As Object, _
                                ByVal e As FormClosedEventArgs) Handles Me.FormClosed
        '-------------------------------------------------------------------------------------------
        ' 設定を退避
        If Me.WindowState = FormWindowState.Normal Then
            ' フォーム表示位置は最小化時は退避させない
            My.Settings.FormLocation = Me.Location                  ' フォーム表示位置
        End If
    End Sub

    '***********************************************************************************************
    '* 処理名　：Form_Load
    '* 機能　　：フォームイベント(Load)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(デフォルト)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月09日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub Form_Load(ByVal sender As Object, _
                          ByVal e As System.EventArgs) Handles Me.Load
        '-------------------------------------------------------------------------------------------
        ' ApplicationEventsへの本フォーム参照の通知
        My.Application.TargetForm = Me
        '-------------------------------------------------------------------------------------------
        With My.Settings
            ' アップグレード時は旧Verの設定を読み込む
            If .UpgradeRequired Then
                .Upgrade()
                .UpgradeRequired = False
                .Save()
            End If
            CCN_PATHNAME.PathName = .RootFolder
            TXT_SearchWord.Text = .SearchWord
        End With
        '-------------------------------------------------------------------------------------------
        ' ステータスストリップの表示文字数をカウント
        Dim intWidth As Integer = StatusStrip1.Width
        ' テキストボックスを一時的に作成して表示可能バイト数取得
        Dim objTextBox As New TextBox
        objTextBox.Font = STS_GUIDE.Font
        objTextBox.Width = intWidth
        g_intStatusLength = FP_GetLengthShowable(objTextBox) - 16
        objTextBox.Dispose()
        objTextBox = Nothing
        '-------------------------------------------------------------------------------------------
        ' フォーム位置制御
        Call g_objAboutWindow.FormAdjustLocationSize1(My.Settings.FormLocation, Me.Size, Me.Size)
    End Sub

    '***********************************************************************************************
    '* 処理名　：Form_Shown
    '* 機能　　：フォームイベント(Shown)
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(デフォルト)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub Form_Shown(ByVal sender As Object, _
                           ByVal e As System.EventArgs) Handles Me.Shown
        '-------------------------------------------------------------------------------------------
        STS_GUIDE.Text = g_cnsStatusGuide & " (Ver" & My.Application.Info.Version.ToString & ")"
        ' 更新日時指定は1年前とする
        DTP_FROM.Value = Today.AddYears(-1)
        DTP_FROM.Checked = False
        Me.Refresh()
        Application.DoEvents()
        ' 初期表示完了
        g_objOmitDoubleClick.Shown = True
    End Sub

    '***********************************************************************************************
    ' ■■■ コントロールイベント ■■■
    '***********************************************************************************************
    '* 処理名　：BTN_OK_Click
    '* 機能　　：｢処理開始｣ボタンClick
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(デフォルト)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub BTN_OK_Click(ByVal sender As Object, _
                             ByVal e As System.EventArgs) Handles BTN_OK.Click
        '-------------------------------------------------------------------------------------------
        ' ダブルクリック等の多重操作を抑制
        If g_objOmitDoubleClick.CheckDoubleClick() Then Exit Sub
        '-------------------------------------------------------------------------------------------
        BTN_OK.Focus()
        Application.DoEvents()
        ' 処理開始
        Call GP_OK_Click()
    End Sub

    '***********************************************************************************************
    '* 処理名　：BTN_PATHNAME_Click
    '* 機能　　：｢フォルダ参照｣ボタンClick
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(デフォルト)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub BTN_PATHNAME_Click(ByVal sender As Object, _
                                   ByVal e As System.EventArgs) Handles BTN_PATHNAME.Click
        '-------------------------------------------------------------------------------------------
        ' ダブルクリック等の多重操作を抑制
        If g_objOmitDoubleClick.CheckDoubleClick() Then Exit Sub
        '-------------------------------------------------------------------------------------------
        ' フォルダの参照ダイアログを表示
        CCN_PATHNAME.ShowFolderBrowserDialog()
    End Sub

    '***********************************************************************************************
    ' ■■■ サブ処理 ■■■
    '***********************************************************************************************
    '* 処理名　：GP_OK_Click
    '* 機能　　：｢処理開始｣ボタンClickサブ
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：(なし)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月10日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Sub GP_OK_Click()
        '-------------------------------------------------------------------------------------------
        ' 入力内容チェック
        If Not FP_CheckForm() Then Exit Sub
        '-------------------------------------------------------------------------------------------
        ' 処理開始確認
        Dim strMSG As String = "本画面の指定内容で処理を開始します。" & ControlChars.CrLf & _
            "よろしいですね？" & ControlChars.CrLf & ControlChars.CrLf & _
            "※処理中はMicrosoft Excel上で別の操作をしないで下さい。" & ControlChars.CrLf & _
            "　操作してしまうと内部動作の競合で異常終了する場合があります。" & _
            ControlChars.CrLf & Strings.Space(1) ' 確認メッセージ
        ' 開始確認メッセージで起動確認
        If MessageBox2.DialogShow( _
            Me, _
            strMSG, _
            g_cnsProgTitle, _
            MessageBoxButtons.YesNo, _
            MessageBoxIcon.Information) <> Windows.Forms.DialogResult.Yes Then Exit Sub
        ' 処理中判定スイッチ対応
        g_objOmitDoubleClick.OmitDoubleClick = True
        '-------------------------------------------------------------------------------------------
        Dim objExcel As Object = Nothing                                ' Excel.Application
        Dim objWBK As Object = Nothing                                  ' Excel.Workbook
        Dim objSH As Object = Nothing                                   ' Excel.Worksheet
        Dim objMsgIcon As MessageBoxIcon = MessageBoxIcon.Error         ' メッセージアイコン
        Dim strMSGHeader As String = "Excel起動中"                      ' メッセージヘッダ
        Dim intReturnValue As Integer = 0                               ' 処理結果
        STS_GUIDE.Text = "Excelを起動しています．．．．"
        Me.Refresh()
        Application.DoEvents()
        ' Excel出力クラスの初期化
        Using clsExcel = New clsAboutExcel2(Me)
            ' Excelを起動し、テンプレートを開く(新規インスタンス)
            If Not clsExcel.GetWorkbook(Path.Combine(FP_GET_AppPath, g_cnsExcelTemplate), _
                                        objWBK, _
                                        strMSGHeader, _
                                        False) Then
                Exit Sub
            End If
            ' 左端シートを取得
            objSH = objWBK.Worksheets(1)
            ' 画面描画停止
            Call clsExcel.StopScreenUpdate()
            '-------------------------------------------------------------------------------------------
            strMSG = String.Empty
            STS_GUIDE.Text = "検索処理実行中．．．．"
            Me.Enabled = False
            Application.DoEvents()
            ' ファイル検索クラス呼び出し
            If OPT_Method1.Checked Then
                ' ①My.Computer.FileSystem.FindInFiles
                With New clsSearchFilesTEST1
                    .prpRootPath = CCN_PATHNAME.PathName
                    .prpSearchWord = TXT_SearchWord.Text.Trim
                    .prpUseLimitDate = DTP_FROM.Checked
                    .prpLimitDate = DTP_FROM.Value
                    ' ファイルの探索
                    intReturnValue = .SearchFiles(objSH)
                    strMSG = .prpReturnMSG
                End With
            ElseIf OPT_Method2.Checked Then
                ' ②System.IOの通常のファイル探索(再帰動作)＋SearchPattern
                With New clsSearchFilesTEST2
                    .prpRootPath = CCN_PATHNAME.PathName
                    .prpSearchWord = TXT_SearchWord.Text.Trim
                    .prpUseLimitDate = DTP_FROM.Checked
                    .prpLimitDate = DTP_FROM.Value
                    ' ファイルの探索
                    intReturnValue = .SearchFiles(objSH)
                    strMSG = .prpReturnMSG
                End With
            ElseIf OPT_Method3.Checked Then
                ' ③System.IOの通常のファイル探索(非再帰動作)＋SearchPattern
                With New clsSearchFilesTEST3
                    .prpRootPath = CCN_PATHNAME.PathName
                    .prpSearchWord = TXT_SearchWord.Text.Trim
                    .prpUseLimitDate = DTP_FROM.Checked
                    .prpLimitDate = DTP_FROM.Value
                    ' ファイルの探索
                    intReturnValue = .SearchFiles(objSH)
                    strMSG = .prpReturnMSG
                End With
            ElseIf OPT_Method4.Checked Then
                ' ④FileSystemObject(VBA同様の再帰動作)＋ファイル名Like判定
                With New clsSearchFilesTEST4
                    .prpRootPath = CCN_PATHNAME.PathName
                    .prpSearchWord = TXT_SearchWord.Text.Trim
                    .prpUseLimitDate = DTP_FROM.Checked
                    .prpLimitDate = DTP_FROM.Value
                    ' ファイルの探索
                    intReturnValue = .SearchFiles(objSH)
                    strMSG = .prpReturnMSG
                End With
            Else
                MessageBox2.DialogShow(Me, _
                                       "対応クラスが見つかりません。", _
                                       g_cnsProgTitle, _
                                       MessageBoxButtons.OK, _
                                       MessageBoxIcon.Error)
                Exit Sub
            End If
            '-------------------------------------------------------------------------------------------
            ' 処理結果判定
            If intReturnValue = 1 Then
                objMsgIcon = MessageBoxIcon.Information
                With My.Settings
                    .RootFolder = CCN_PATHNAME.PathName
                    .SearchWord = TXT_SearchWord.Text
                End With
            End If
            '-------------------------------------------------------------------------------------------
            ' 終了
            STS_GUIDE.Text = g_cnsStatusGuide & " (Ver" & My.Application.Info.Version.ToString & ")"
            Me.Enabled = True
            Application.DoEvents()
            ' Excel出力の終了
            Call clsExcel.SuspendExcelProc(objWBK, True)
        End Using
        ' 終了メッセージ
        MessageBox2.DialogShow(Me, _
                               strMSG, _
                               g_cnsProgTitle, _
                               MessageBoxButtons.OK, _
                               objMsgIcon)
    End Sub

    '***********************************************************************************************
    '* 処理名　：FP_CheckForm
    '* 機能　　：フォーム項目チェック
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：処理正否(Boolean)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Function FP_CheckForm() As Boolean
        '-------------------------------------------------------------------------------------------
        Dim strMSG As String = String.Empty                             ' エラーメッセージ
        ' ルートフォルダ
        If CCN_PATHNAME.ErrValue <> 0 Then
            Call GP_AppendMessage(strMSG, CCN_PATHNAME.ErrMSG)
        End If
        ' 検索文字列
        If TXT_SearchWord.Text.ToString.Trim.Length = 0 Then
            Call GP_AppendMessage(strMSG, "「検索文字列」が指定されていません。")
        End If
        ' 更新日時指定
        If ((DTP_FROM.Checked) AndAlso (DTP_FROM.Value > Today)) Then
            Call GP_AppendMessage(strMSG, "「更新日時指定」が未来日です。")
        End If
        '-------------------------------------------------------------------------------------------
        ' エラーがあるか
        If strMSG.Length <> 0 Then
            MessageBox2.DialogShow(Me, _
                                   strMSG, _
                                   g_cnsProgTitle, _
                                   MessageBoxButtons.OK, _
                                   MessageBoxIcon.Exclamation)
            Return False
        Else
            Return True
        End If
    End Function

    '***********************************************************************************************
    '* 処理名　：FP_GET_AppPath
    '* 機能　　：本アプリケーション(exe)の所在フォルダの取得
    '-----------------------------------------------------------------------------------------------
    '* 返り値　：パス名(String)
    '* 引数　　：(なし)
    '-----------------------------------------------------------------------------------------------
    '* 作成日　：2017年12月02日
    '* 作成者　：井上　治
    '* 更新日　：2017年12月02日
    '* 更新者　：井上　治
    '* 機能説明：
    '* 注意事項：
    '***********************************************************************************************
    Private Function FP_GET_AppPath() As String
        '-------------------------------------------------------------------------------------------
        Return Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location)
    End Function

    '----------------------------------------<< End of Source >>------------------------------------
End Class
